@@ -81,7 +81,10 @@ def ProcessFiles(sourceFile):
                         if not ymlRegex.fullmatch(piece):
                             targetContent += piece
                         else:
-                            localized = 'name: ' + Translate(piece[6:], langCombo).title()
+                            word = Translate(piece[6:], langCombo).title()
+                            if word == None:
+                                break
+                            localized = 'name: ' + word
                             targetContent += localized
             else:
                 if sourceLang[:2] == 'en':
@@ -106,11 +109,16 @@ def ProcessFiles(sourceFile):
                         if mdRegex.fullmatch(piece):
                             if re.fullmatch(r'\]\(#.+\)', piece):
                                 anchor = Translate(' '.join(piece[3:-1].split('-')), langCombo)
+                                if anchor == None:
+                                    break
                                 targetContent += '](#' + '-'.join(anchor.split(' ')).lower() + ')'
                             else:
                                 targetContent += piece
                         else:
-                            localized = Translate(piece, langCombo)
+                            word = Translate(piece, langCombo)
+                            if word == None:
+                                break
+                            localized = word
                             if type(localized) is list:
                                 localized = localized[0]
                             targetContent += localized
@@ -148,14 +156,19 @@ def FileStats(sourceFile):
 def Translate(text, langCombo):
     if re.search(r'\w', text) is None: return [text for n in targetLangs]
     firstLetter = re.search(r'\w', text).group()
-    resp = requests.get(
-        urlTrad,
-        params = {
-            'key': apiTradKey,
-            'lang': langCombo,
-            'text': text
-            }
-    )
+    try:
+        resp = requests.get(
+            urlTrad,
+            params = {
+                'key': apiTradKey,
+                'lang': langCombo,
+                'text': text
+                },
+            timeou = 1
+        )
+    except requests.Timeout:
+        PrYellow('A request timed out!')
+        return None
     if resp.status_code != 200:
         PrRed('Request failed!')
         exit()
@@ -188,10 +201,10 @@ def RepoCheck():
     global sourceDir
     if sourceLang not in os.listdir():
         if sourceLang + '_' not in list(map(lambda x: x[:3], os.listdir())):
-            PrRed('\nNo directory for source language files has been found!\n Add or rename the directory with the ISO 639-1 code for its language')
+            PrRed('\nNo directory for source language files has been found!\nAdd or rename the directory with the ISO 639-1 code for its language')
         else:
             if len(list(filter(lambda x: x == sourceLang + '_', map(lambda x: x[:3], os.listdir())))) > 1:
-                PrRed('\nThere are more than one directory named with source language code.\n Please designate only one.')
+                PrRed('\nThere are more than one directory named with source language code.\nPlease designate only one.')
             else:
                 sourceDir = list(filter(lambda x: x[:3] == sourceLang + '_', os.listdir()))[0]
     else:
